@@ -114,7 +114,7 @@ except NameError:
     DEAD_ENGINE_ERRORS = (EOFError, IOError)
 
 
-__version__ = "1.16.8"
+__version__ = "1.16.11"
 
 __author__ = "Bajusz Tamás"
 __email__ = "gbtami@gmail.com"
@@ -140,26 +140,33 @@ LVL_DEPTHS = [1, 1, 1, 2, 3, 5, 8, 13, 22]
 NNUE_NET = {
     "asean": "88c4f9118f34",
     "atomic": "4ecb2067c716",
-    "capablanca": "e605d6d3dd31",
+    "capablanca": "f362875966da",
+    "capahouse": "9410dee8f2a3",
     "chak": "0dfa519b8ee7",
-    "crazyhouse": "f0782c10a2d4",
+    "chennis": "88897e88b42a",
+    "crazyhouse": "0adf5579efa2",
     "empire": "d14c0d04359e",
+    "gorogoroplus": "7bc64726c1c1",
     "grand": "596776a80f03",
+    "grandhouse": "35c216476fc5",
+    "hoppelpoppel": "ca81db235bbe",
     "janggi": "ffbf1d95cea2",
     "makpong": "75299b96ab1d",
     "makruk": "e14ecd7ae145",
     "minishogi": "32efe2ac350b",
+    "minixiangqi": "e405be9a6bba",
     "nn": "46832cfbead3",
     "orda": "af8fab8f210b",
     "ordamirror": "b432a42e3738",
-    "seirawan": "d6ec9a356fa8",
+    "seirawan": "11923f7962b3",
     "shinobi": "4abe32d99161",
     "shogi": "878ca61334a7",
     "shogun": "04b4fe4bbad7",
+    "shouse": "a9ca0fc73863",
     "sittuyin": "3c3ed74dbe54",
     "synochess": "42aaabb0581f",
     "torishogi": "0c3670e88a63",
-    "xiangqi": "28d6221e2440",
+    "xiangqi": "bd62afd13f7c",
 }
 
 NNUE_ALIAS = {
